% startV2.m   ... vypocet polohy kyvadla (hmotny bod na nehmotnem lane)
% verze 2 s otocenym souradnicovym systeme - svisla osa je y
clear all   % vycisti pamet od vsech promennych
close all   % zavre vsechna otevrena okna (grafy apod.)

global m l G     % deklarace globalnich promennych

% parametry
m=20;        % hmotnost [kg]
l=1;         % delka zavesu  [m]
G=m*9.81;    % tiha [N]

% nastaveni delky experimentu (s)
tstart=0;
tkonec=12;

% nastaveni maximalni velikosti kroku pri integraci
options=odeset('MaxStep',0.01);

z0=[pi/2,0,pi/2,0];   % pocatecni podminky [fi,fid,psi,psid]

[t,z]=ode45(@zdotV2,[tstart:0.02:tkonec],z0,options);  % integrace

fi=z(:,1);
fit=z(:,2);
psi=z(:,3);
psit=z(:,4);

% buzeni
[xp,yp,zp]=buzeniV2([tstart:0.02:tkonec]');
% xp=zeros(size(fi));      % pro pripad s pevnym zavesem
% yp=zeros(size(fi));      % pro pripad s pevnym zavesem
% zp=zeros(size(fi));      % pro pripad s pevnym zavesem

% vypocet souradnic [x,y,z] pozice kyvadla
x=l*sin(fi).*cos(psi)+xp;
y=l*sin(fi).*sin(psi)+yp;
z=-l*cos(fi)+zp;

% vykresleni - protoze je v tomto modelu system otoceny tak, ze osa y
% smeruje dolu a osa z je vodorovna, zatimco Matlab vykresluje y vodorovne
% a z svisle, jsou zde prohozeny osy y/z 
figure      % otevre novy obrazek
for i=1:length(x)
    plot3(xp(i),zp(i),-yp(i),'kv','LineWidth',3); hold on  % misto zaveseni
    plot3(xp(i),zp(i),-1.5,'k+','LineWidth',3);            % 'stin' mista zaveseni
    plot3(xp(1:i),zp(1:i),-yp(1:i),'b');                   % draha mista zaveseni
    plot3(x(i),z(i),-y(i),'ro','LineWidth',5);             % hmotny bod
    plot3([xp(i),x(i)],[zp(i),z(i)],[-yp(i),-y(i)],'r-','LineWidth',2); % lano     
    plot3(x(i),z(i),-1.5,'ko','LineWidth',5);              % 'stin' hm. bodu
    axis square;                          % ctvercove osy
    axis([-1 1 -1 1 -1.5 0.5])            % rozsah os
    grid on                               % zobrazeni mrizky
    hold off        % nic dalsiho uz do obrazku nebudeme kreslit 
    drawnow         % vykresleni
end





